# Container for scaling up the prototype
container = new Layer
	width: 320
	height: 568
	backgroundColor: null
	originX: 0
	originY: 0
	scale: Screen.height / 568

# Page Component that holds the 6 pages
page = new PageComponent
	size: container.size
	parent: container
	scrollVertical: no

# PAGE 1
page.addPage page_1_content

# add icons to the «container», so that they also scale
for icon in [instagram, calendar, soundcloud, stocks, gmail, facebook, rss_feed, weather]
	icon.parent = container

# move a few things to the front
page.bringToFront()
instagram.bringToFront()
calendar.bringToFront()

# save the icons’ initial x positions
w_x = weather.x
r_x = rss_feed.x
f_x = facebook.x
g_x = gmail.x
s_x = stocks.x
sc_x = soundcloud.x
i_x = instagram.x
c_x = calendar.x

# PAGE 2
page.addPage page_2_content

# save initial x position of the recipe
i_recipe_x = instagram_recipe.x

# PAGE 3
page.addPage page_3_content

# save initial x position of the arrows
r_arrow_x = recipe_arrows.x

# PAGE 4
page.addPage page_4_content

# PAGE 5
page.addPage page_5_content

# Repositioning the images for page four

# moving them to this screen
phone_and_trails.parent = container
ios_photos.parent = container
ios_notif.parent = container
ios_location.parent = container
ios_contacts.parent = container

# saving their end positions
phone_and_trails.saved = phone_and_trails.point
ios_photos.saved = ios_photos.point
ios_notif.saved = ios_notif.point
ios_location.saved = ios_location.point
ios_contacts.saved = ios_contacts.point

# … and moving them off the screen, ready to move up
for layer in [phone_and_trails, ios_photos, ios_notif, ios_location, ios_contacts]
	layer.y += page.height	# one screen height down

# Positions of the app icons on page 5
ios_photos.p5 =
	x: 82
	y: 244

ios_location.p5 =
	x: 84
	y: 114

ios_contacts.p5 =
	x: 82
	y: 373

# PAGE 6
page.addPage page_6_content

white_button.onTapStart ->
	this.animate
		opacity: 0.75
		options:
			time: 0.2

white_button.onTapEnd ->
	this.animate
		opacity: 1
		options:
			time: 0.2


# Move event
page.onMove ->
	# from page 1 to page 2
	weather.x		= w_x  + ( page.scrollX * 1.7 )
	rss_feed.x		= r_x  + ( page.scrollX * 0.9 )
	facebook.x		= f_x  + ( page.scrollX * 0.55 )
	gmail.x			= g_x  + ( page.scrollX * 0.4 )
	stocks.x		= s_x  + ( page.scrollX * 1.5 )
	soundcloud.x	= sc_x + page.scrollX
	instagram.x		= i_x  + ( page.scrollX * 1.5 )
	calendar.x		= c_x  + ( page.scrollX * 1.3 )
	
	# from page 2 to page 3
	instagram_recipe.x = Utils.modulate page.scrollX,
		[page.width, page.width * 2], 
		[i_recipe_x, i_recipe_x + page.width], yes
	
	# from page 3 to page 4
	recipe_arrows.x = Utils.modulate page.scrollX,
		[page.width * 2, page.width * 3], 
		[r_arrow_x, r_arrow_x - (page.width * 1.5)],
		yes
	
	phone_and_trails.y = Utils.modulate page.scrollX,
		[page.width * 2, page.width * 3],
		[phone_and_trails.saved.y + page.height, phone_and_trails.saved.y],
		yes
	
	for trail in [trail_left, trail_c_left, trail_c_right, trail_right]
		trail.scaleX = Utils.modulate page.scrollX,
					[page.width * 2, page.width * 3],
					[0.1, 1], yes
		trail.opacity = Utils.modulate page.scrollX,
					[page.width * 2.4, page.width * 3],
					[0, 1], yes
	
	for icon in [ios_photos, ios_notif, ios_location, ios_contacts]
		icon.y = Utils.modulate page.scrollX,
					[page.width * 2, page.width * 3],
					[icon.saved.y + page.height, icon.saved.y],
					yes
		icon.scale = Utils.modulate page.scrollX,
					[page.width * 2, page.width * 3],
					[0.50, 1], yes
	
	# from page 4 to page 5
	phone_and_trails.x = Utils.modulate page.scrollX,
				[page.width * 3, page.width * 4],
				[0, -page.width], yes
	
	for trail in [trail_left, trail_c_left, trail_c_right, trail_right]
		trail.opacity = Utils.modulate page.scrollX,
					[page.width * 3, (page.width * 3) + 20], 
					[1, 0], yes
	
	ios_notif.opacity = Utils.modulate page.scrollX,
				[page.width*3, (page.width*3)+50],
				[1,0], yes
	
	ios_notif.x = Utils.modulate page.scrollX,
				[page.width * 3, page.width * 4],
				[ios_notif.saved.x, ios_notif.saved.x - page.width],
				yes
	
	# limitation, to not override earlier changes
	if page.scrollX >= page.width * 3
		for icon in [ios_photos, ios_location, ios_contacts]
			icon.size = Utils.modulate page.scrollX,
					[page.width * 3, page.width * 4],
					[91, 40], yes
			icon.x = Utils.modulate page.scrollX,
					[page.width * 3, page.width * 4],
					[icon.saved.x, icon.p5.x],
					yes
			icon.y = Utils.modulate page.scrollX,
					[page.width * 3, page.width * 4],
					[icon.saved.y, icon.p5.y],
					yes
	
	# from page 5 to page 6
	if page.scrollX >= page.width * 4
		
		for icon in [ios_photos, ios_location, ios_contacts]
			icon.x = Utils.modulate page.scrollX,
					[page.width * 4, page.width * 5],
					[icon.p5.x, icon.p5.x - page.width],
					yes
		
		white_button.x = Utils.modulate page.scrollX,
			[page.width * 4, page.width * 6],
			[page.width + 25, -page.width + 25], yes
		
		banner_sign_in.x = Utils.modulate page.scrollX,
			[page.width * 4, page.width * 6], 
			[(page.width*.5) + 25, -(page.width*.5) + 25],
			yes
	